@@ -163,13 +163,13 @@ typedef struct {
 
 struct TrackerResultIterator {
 #ifdef HAVE_DBUS_FD_PASSING
-	char *buffer;
-	int buffer_index;
-	long buffer_size;
+	gchar *buffer;
+	gint buffer_index;
+	gssize buffer_size;
 
 	guint n_columns;
-	int *offsets;
-	char *data;
+	gint *offsets;
+	gchar *data;
 #else  /* HAVE_DBUS_FD_PASSING */
 	GPtrArray *results;
 	gint current_row;
@@ -658,14 +658,21 @@ callback_iterator (void     *buffer,
 		tracker_result_iterator_free (iterator);
 	} else {
 		if (error->code != G_IO_ERROR_CANCELLED) {
-			g_clear_error (&error);
-			g_set_error (&error,
-			             TRACKER_CLIENT_ERROR,
-			             TRACKER_CLIENT_ERROR_BROKEN_PIPE,
-			             "Couldn't get results from server");
+			GError *iterator_error;
 
-			(* fad->iterator_callback) (NULL, error, fad->user_data);
+			iterator_error = g_error_new (TRACKER_CLIENT_ERROR,
+			                              TRACKER_CLIENT_ERROR_BROKEN_PIPE,
+			                              "Couldn't get results from server");
+
+			(* fad->iterator_callback) (NULL, iterator_error, fad->user_data);
+
+			/* iterator_error was passed to the callback and should be
+			 * disposed there */
 		}
+
+		/* Always free input GError. We want to behave exactly as if this
+		 * callback were one used in an async dbus-glib query.  */
+		g_error_free (error);
 	}
 
 	fast_async_data_free (fad);
@@ -1031,6 +1038,7 @@ sparql_update_fast_callback (DBusPendingCall *call,
 
 		fast_async_data_free (fad);
 
+		dbus_pending_call_unref (call);
 		return;
 	}
 
@@ -1072,6 +1080,8 @@ sparql_update_fast_callback (DBusPendingCall *call,
 	dbus_message_unref (reply);
 
 	fast_async_data_free (fad);
+
+	dbus_pending_call_unref (call);
 }
 
 static DBusPendingCall *
