@@ -35,7 +35,7 @@
 #include <libtracker-extract/tracker-extract.h>
 
 typedef struct {
-	gchar *creator;
+	const gchar *creator;
 } MergeData;
 
 typedef struct {
@@ -106,7 +106,7 @@ extract_vorbis (const char *uri,
 	MergeData md = { 0 };
 	FILE *f;
 	gchar *filename;
-	OggVorbis_File  vf;
+	OggVorbis_File vf;
 	vorbis_comment *comment;
 	vorbis_info *vi;
 	unsigned int bitrate;
@@ -169,7 +169,7 @@ extract_vorbis (const char *uri,
 		vorbis_comment_clear (comment);
 	}
 
-	md.creator = tracker_coalesce (3, vd.artist, vd.album_artist, vd.performer);
+	md.creator = tracker_coalesce_strip (3, vd.artist, vd.album_artist, vd.performer);
 
 	if (md.creator) {
 		gchar *uri = tracker_uri_printf_escaped ("urn:artist:%s", md.creator);
@@ -181,7 +181,6 @@ extract_vorbis (const char *uri,
 		tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
 		tracker_sparql_builder_object_unvalidated (preupdate, md.creator);
 		tracker_sparql_builder_insert_close (preupdate);
-		g_free (md.creator);
 
 		tracker_sparql_builder_predicate (metadata, "nmm:performer");
 		tracker_sparql_builder_object_iri (metadata, uri);
@@ -436,6 +435,10 @@ extract_vorbis (const char *uri,
 		tracker_sparql_builder_object_int64 (metadata, (gint64) time);
 	}
 
+	g_free (vd.artist);
+	g_free (vd.album_artist);
+	g_free (vd.performer);
+
 	/* NOTE: This calls fclose on the file */
 	ov_clear (&vf);
 }
