@@ -100,11 +100,27 @@ dbus_register_object (DBusGConnection       *lconnection,
 	dbus_g_connection_register_g_object (lconnection, path, object);
 }
 
-static gboolean
-dbus_register_names (void)
+gboolean
+tracker_dbus_register_names (void)
+{
+	/* Register the service name for org.freedesktop.Tracker */
+	if (!dbus_register_service (gproxy, TRACKER_STATISTICS_SERVICE)) {
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+gboolean
+tracker_dbus_init (void)
 {
 	GError *error = NULL;
 
+	/* Don't reinitialize */
+	if (objects) {
+		return TRUE;
+	}
+
 	if (connection) {
 		g_critical ("The DBusGConnection is already set, have we already initialized?");
 		return FALSE;
@@ -132,27 +148,6 @@ dbus_register_names (void)
 	                                    DBUS_PATH_DBUS,
 	                                    DBUS_INTERFACE_DBUS);
 
-	/* Register the service name for org.freedesktop.Tracker */
-	if (!dbus_register_service (gproxy, TRACKER_STATISTICS_SERVICE)) {
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
-gboolean
-tracker_dbus_init (void)
-{
-	/* Don't reinitialize */
-	if (objects) {
-		return TRUE;
-	}
-
-	/* Register names and get proxy/connection details */
-	if (!dbus_register_names ()) {
-		return FALSE;
-	}
-
 	dbus_g_proxy_add_signal (gproxy, "NameOwnerChanged",
 	                         G_TYPE_STRING,
 	                         G_TYPE_STRING,
@@ -162,27 +157,6 @@ tracker_dbus_init (void)
 	return TRUE;
 }
 
-void
-tracker_dbus_shutdown (void)
-{
-	tracker_dbus_set_available (FALSE);
-
-	if (backup) {
-		g_object_unref (backup);
-	}
-
-	if (notifier) {
-		g_object_unref (notifier);
-	}
-
-	if (gproxy) {
-		g_object_unref (gproxy);
-		gproxy = NULL;
-	}
-
-	connection = NULL;
-}
-
 static void
 name_owner_changed_cb (DBusGProxy *proxy,
                        gchar      *name,
@@ -196,8 +170,14 @@ name_owner_changed_cb (DBusGProxy *proxy,
 	}
 }
 
-void
-tracker_dbus_set_available (gboolean available)
+static void
+name_owner_changed_closure (gpointer  data,
+                            GClosure *closure)
+{
+}
+
+static void
+dbus_set_available (gboolean available)
 {
 	if (available) {
 		if (!objects) {
@@ -223,10 +203,25 @@ tracker_dbus_set_available (gboolean available)
 	}
 }
 
-static void
-name_owner_changed_closure (gpointer  data,
-                            GClosure *closure)
+void
+tracker_dbus_shutdown (void)
 {
+	dbus_set_available (FALSE);
+
+	if (backup) {
+		g_object_unref (backup);
+	}
+
+	if (notifier) {
+		g_object_unref (notifier);
+	}
+
+	if (gproxy) {
+		g_object_unref (gproxy);
+		gproxy = NULL;
+	}
+
+	connection = NULL;
 }
 
 TrackerStatus*
@@ -256,9 +251,6 @@ tracker_dbus_register_notifier (void)
 gboolean
 tracker_dbus_register_objects (void)
 {
-	TrackerDBResultSet *result_set;
-	GSList *event_sources = NULL;
-	GStrv classes, p;
 	gpointer object, resources;
 
 	if (!connection || !gproxy) {
@@ -335,6 +327,25 @@ tracker_dbus_register_objects (void)
 		 * work correctly from the dbus call otherwise */
 	}
 
+	return TRUE;
+	
+}
+
+gboolean
+tracker_dbus_register_class_signal_objects (void)
+{
+	TrackerDBResultSet *result_set;
+	GSList *event_sources = NULL;
+	GStrv classes, p;
+	gpointer object, resources;
+
+	resources = tracker_dbus_get_object (TRACKER_TYPE_RESOURCES);
+
+	if (!resources) {
+		g_message ("Error during initialization, Resources DBus object not available");
+		return TRUE;
+	}
+
 	result_set = tracker_data_query_sparql ("SELECT ?class WHERE { ?class tracker:notify true }", NULL);
 
 	if (!result_set) {
