@@ -331,6 +331,8 @@ class rtcom(TestUpdate):
 # Current rtcom queries, please do not "quietly optimize".
 #
 
+# requires secondary index support to be fast
+
 		query = " \
 SELECT ?message ?date ?from ?to \
      rdf:type(?message) \
@@ -361,35 +363,43 @@ SELECT ?message ?date ?from ?to \
      nie:language(?message) \
 WHERE \
 { \
-  { \
-    ?message a nmo:Message . \
-    ?message nmo:isDraft false . \
-    ?message nmo:isDeleted false . \
-    ?message nmo:receivedDate ?date . \
-    ?message nmo:from ?fromContact . \
-    ?message nmo:to ?toContact . \
-    ?fromContact nco:hasContactMedium ?from . \
-    ?toContact nco:hasContactMedium ?to . \
-    ?message nmo:communicationChannel <urn:channel:1> . \
-    <urn:channel:1> nmo:hasParticipant ?participant . \
-      OPTIONAL \
+  SELECT \
+     ?message ?date ?from ?to \
+     (SELECT ?contact \
+      WHERE \
       { \
-        ?contact a nco:PersonContact . \
           { \
+            <urn:channel:1> nmo:hasParticipant ?participant . \
+            ?contact a nco:PersonContact . \
             ?participant nco:hasIMAddress ?imaddress . \
             ?contact nco:hasIMAddress ?imaddress . \
           } \
           UNION \
           { \
+            <urn:channel:1> nmo:hasParticipant ?participant . \
+            ?contact a nco:PersonContact . \
             ?participant nco:hasPhoneNumber ?participantNumber . \
             ?participantNumber maemo:localPhoneNumber ?number . \
             ?contact nco:hasPhoneNumber ?contactNumber . \
             ?contactNumber maemo:localPhoneNumber ?number . \
           } \
       } \
+     ) AS ?contact \
+  WHERE \
+  { \
+    ?message a nmo:Message . \
+    ?message nmo:isDraft false . \
+    ?message nmo:isDeleted false . \
+    ?message nmo:sentDate ?date . \
+    ?message nmo:from ?fromContact . \
+    ?message nmo:to ?toContact . \
+    ?fromContact nco:hasContactMedium ?from . \
+    ?toContact nco:hasContactMedium ?to . \
+    ?message nmo:communicationChannel <urn:channel:1> . \
   } \
+  ORDER BY DESC(?date) \
 } \
-ORDER BY DESC(?date) LIMIT 50\
+LIMIT 50 \
 "
 
         	start=time.time()
@@ -405,35 +415,41 @@ ORDER BY DESC(?date) LIMIT 50\
 # Current rtcom queries, please do not "quietly optimize".
 #
 		query = " \
-SELECT ?channel ?participant ?subject nie:generator(?channel) ?contactName ?contactUID ?lastDate ?lastMessage nie:plainTextContent(?lastMessage) \
+SELECT ?channel ?subject nie:generator(?channel) \
+  tracker:coalesce(fn:concat(nco:nameGiven(?contact), ' ', nco:nameFamily(?contact)), nco:nickname(?contact)) AS ?contactName \
+  nco:contactUID(?contact) AS ?contactUID \
+  ?lastDate ?lastMessage nie:plainTextContent(?lastMessage) \
   nfo:fileName(nmo:fromVCard(?lastMessage)) \
   rdfs:label(nmo:fromVCard(?lastMessage)) \
   ( SELECT COUNT(?message) AS ?total_messages WHERE { ?message nmo:communicationChannel ?channel . }) \
   ( SELECT COUNT(?message) AS ?total_unread   WHERE { ?message nmo:communicationChannel ?channel . ?message nmo:isRead false  .}) \
   ( SELECT COUNT(?message) AS ?_total_sent    WHERE { ?message nmo:communicationChannel ?channel . ?message nmo:isSent true . }) \
 WHERE { \
-  SELECT ?channel ?participant nco:contactUID(?contact) AS ?contactUID ?subject  ?lastDate \
-         tracker:coalesce(fn:concat(nco:nameGiven(?contact), ' ', nco:nameFamily(?contact)), nco:nickname(?contact)) AS ?contactName \
+  SELECT ?channel  ?subject  ?lastDate \
+          \
          ( SELECT ?message WHERE {?message nmo:communicationChannel ?channel . ?message nmo:sentDate ?sentDate .} ORDER BY DESC(?sentDate) LIMIT 1) AS ?lastMessage \
-  WHERE { \
-      ?channel a nmo:CommunicationChannel . \
-      ?channel nmo:hasParticipant ?participant . \
-      ?channel nie:subject ?subject . \
-      ?channel nmo:lastMessageDate ?lastDate . \
-      OPTIONAL { \
-            ?contact a nco:PersonContact . \
+      (SELECT ?contact \
+      WHERE { \
             { \
+              ?channel nmo:hasParticipant ?participant . \
+              ?contact a nco:PersonContact . \
               ?participant nco:hasIMAddress ?imaddress . \
               ?contact nco:hasIMAddress ?imaddress . \
             } \
             UNION \
             { \
+              ?channel nmo:hasParticipant ?participant . \
+              ?contact a nco:PersonContact . \
               ?participant nco:hasPhoneNumber ?participantNumber . \
               ?number maemo:localPhoneNumber ?localNumber . \
               ?contact nco:hasPhoneNumber ?contactNumber . \
               ?contactNumber maemo:localPhoneNumber ?localNumber . \
             } \
-        } \
+        }) AS ?contact \
+  WHERE { \
+      ?channel a nmo:CommunicationChannel . \
+      ?channel nie:subject ?subject . \
+      ?channel nmo:lastMessageDate ?lastDate . \
     } \
 } \
 ORDER BY DESC(?lastDate) LIMIT 50\
@@ -455,8 +471,6 @@ ORDER BY DESC(?lastDate) LIMIT 50\
 		query = " \
 SELECT ?call ?date ?from ?to \
      rdf:type(?call) \
-     tracker:coalesce(fn:concat(nco:nameGiven(?contact), ' ', nco:nameFamily(?contact)), nco:nickname(?contact)) \
-     ?contactId \
      nmo:isSent(?call) \
      nmo:isAnswered(?call) \
      nmo:isRead(?call) \
@@ -464,44 +478,56 @@ SELECT ?call ?date ?from ?to \
      nmo:receivedDate(?call) \
      nmo:duration(?call) \
      nie:contentLastModified(?call) \
-WHERE \
-{ \
-  { \
-    ?call a nmo:Call . \
-    ?call nmo:receivedDate ?date . \
-    ?call nmo:from ?fromContact . \
-    ?call nmo:to ?toContact . \
-    ?fromContact nco:hasContactMedium ?from . \
-    ?toContact nco:hasContactMedium ?to . \
-      OPTIONAL \
+     (SELECT ?contact \
+      WHERE \
       { \
-        ?contact a nco:PersonContact . \
-        ?contact nco:contactUID ?contactId . \
-          { \
-            ?call nmo:to ?address . \
-          } \
-          UNION \
-          { \
-            ?call nmo:from ?address . \
-          } \
           { \
+              ?contact a nco:PersonContact . \
+              ?contact nco:contactUID ?contactId . \
+              { \
+                ?call nmo:to ?address . \
+              } \
+              UNION \
+              { \
+                ?call nmo:from ?address . \
+              } \
             ?address nco:hasIMAddress ?imaddress . \
             ?contact nco:hasIMAddress ?imaddress . \
           } \
           UNION \
           { \
+              ?contact a nco:PersonContact . \
+              ?contact nco:contactUID ?contactId . \
+              { \
+                ?call nmo:to ?address . \
+              } \
+              UNION \
+              { \
+                ?call nmo:from ?address . \
+              } \
             ?address nco:hasPhoneNumber ?addressNumber . \
             ?addressNumber maemo:localPhoneNumber ?number . \
             ?contact nco:hasPhoneNumber ?contactNumber . \
             ?contactNumber maemo:localPhoneNumber ?number . \
           } \
-      } \
+      }) \
+WHERE \
+{ \
+  { \
+    ?call a nmo:Call . \
+    ?call nmo:sentDate ?date . \
+    ?call nmo:from ?fromContact . \
+    ?call nmo:to ?toContact . \
+    ?fromContact nco:hasContactMedium ?from . \
+    ?toContact nco:hasContactMedium ?to . \
   } \
 } \
 ORDER BY DESC(?date) LIMIT 50\
 "
 
 
+
+
         	start=time.time()
 
 		result=self.resources.SparqlQuery(query)
@@ -839,7 +865,7 @@ class gallery(TestUpdate):
 
 		query = "SELECT ?media WHERE { \
                      	?media a nfo:Visual; \
-                        nmm:camera 'NOKIA' }"
+                        nfo:device 'NOKIA' }"
 
 		start=time.time()
 
@@ -856,7 +882,7 @@ class gallery(TestUpdate):
 
 		query = "SELECT ?media WHERE { \
                      	?media a nfo:Visual; \
-                        nmm:camera 'NOKIA' } LIMIT 500"
+                        nfo:device 'NOKIA' } LIMIT 500"
 
 		start=time.time()
 
@@ -877,7 +903,7 @@ class gallery(TestUpdate):
 			nie:mimeType ?mime. \
 			OPTIONAL { ?image nfo:height ?height .}\
 			OPTIONAL { ?image nfo:width  ?width .}\
-			OPTIONAL { ?image nmm:camera ?camera .}\
+			OPTIONAL { ?image nfo:device ?camera .}\
 			OPTIONAL { ?image nmm:exposureTime ?exposuretime .}\
 			OPTIONAL { ?image nmm:fnumber ?fnumber .}\
 			OPTIONAL { ?image nmm:focalLength ?focallength .}} LIMIT 10000"
@@ -904,7 +930,7 @@ class gallery(TestUpdate):
 			nie:mimeType ?mime. \
 			OPTIONAL { ?image nfo:height ?height .}\
 			OPTIONAL { ?image nfo:width  ?width .}\
-			OPTIONAL { ?image nmm:camera ?camera .}\
+			OPTIONAL { ?image nfo:device ?camera .}\
 			OPTIONAL { ?image nmm:exposureTime ?exposuretime .}\
 			OPTIONAL { ?image nmm:fnumber ?fnumber .}\
 			OPTIONAL { ?image nmm:focalLength ?focallength .}} LIMIT 500"
@@ -945,7 +971,7 @@ class gallery(TestUpdate):
 		"""Querying all images """
 		"""simplified version of test_gallery_09 """
 
-		query = "SELECT nie:url(?image) nfo:height(?image) nfo:width(?image) nie:mimeType(?image) nmm:camera(?image) nmm:exposureTime(?image) nmm:fnumber(?image) nmm:focalLength(?image) WHERE { ?image a nmm:Photo . } limit 10000"
+		query = "SELECT nie:url(?image) nfo:height(?image) nfo:width(?image) nie:mimeType(?image) nfo:device(?image) nmm:exposureTime(?image) nmm:fnumber(?image) nmm:focalLength(?image) WHERE { ?image a nmm:Photo . } limit 10000"
 
 
 		start=time.time()
@@ -961,7 +987,7 @@ class gallery(TestUpdate):
 		"""Querying 500 images """
 		"""simplified version of test_gallery_10 """
 
-		query = "SELECT nie:url(?image) nfo:height(?image) nfo:width(?image) nie:mimeType(?image) nmm:camera(?image) nmm:exposureTime(?image) nmm:fnumber(?image) nmm:focalLength(?image) WHERE { ?image a nmm:Photo . } limit 500"
+		query = "SELECT nie:url(?image) nfo:height(?image) nfo:width(?image) nie:mimeType(?image) nfo:device(?image) nmm:exposureTime(?image) nmm:fnumber(?image) nmm:focalLength(?image) WHERE { ?image a nmm:Photo . } limit 500"
 
 
 		start=time.time()
@@ -1876,6 +1902,525 @@ ORDER BY ?_contact LIMIT 50 \
 		print "Time taken to get 50 contacts phone number information (modified) %s " %elapse
 		print "no. of items retrieved: %d" %len(result)
 
+class location (TestUpdate) :
+
+        def p_test_location_01 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon ?cAlt ?cRad \
+  ?nwLat ?nwLon ?nwAlt \
+  ?seLat ?seLon ?seAlt \
+  ?country ?district ?city ?street ?postalcode \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asPostalAddress \
+            [ \
+              a nco:PostalAddress ; \
+              nco:country ?country ; \
+              nco:region ?district ; \
+              nco:locality ?city ; \
+              nco:streetAddress ?street ; \
+              nco:postalcode ?postalcode \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asBoundingBox \
+            [ \
+              a mlo:GeoBoundingBox ; \
+              mlo:bbNorthWest \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?nwLat ; \
+                  mlo:longitude ?nwLon ; \
+                  mlo:altitude ?nwAlt \
+                ] ; \
+              mlo:bbSouthEast \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?seLat ; \
+                  mlo:longitude ?seLon ; \
+                  mlo:altitude ?seAlt \
+                ] \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:latitude ?cLat ; \
+              mlo:longitude ?cLon \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:altitude ?cAlt \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:radius ?cRad \
+            ] \
+        ] \
+    } \
+} ORDER BY ASC(?name) LIMIT 50 \
+"
+
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get 50 landmarks (original) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+        def p_test_location_02 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon ?cAlt ?cRad \
+  ?nwLat ?nwLon ?nwAlt \
+  ?seLat ?seLon ?seAlt \
+  ?country ?district ?city ?street ?postalcode \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asPostalAddress \
+            [ \
+              a nco:PostalAddress ; \
+              nco:country ?country ; \
+              nco:region ?district ; \
+              nco:locality ?city ; \
+              nco:streetAddress ?street ; \
+              nco:postalcode ?postalcode \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asBoundingBox \
+            [ \
+              a mlo:GeoBoundingBox ; \
+              mlo:bbNorthWest \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?nwLat ; \
+                  mlo:longitude ?nwLon ; \
+                  mlo:altitude ?nwAlt \
+                ] ; \
+              mlo:bbSouthEast \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?seLat ; \
+                  mlo:longitude ?seLon ; \
+                  mlo:altitude ?seAlt \
+                ] \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:latitude ?cLat ; \
+              mlo:longitude ?cLon \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:altitude ?cAlt \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:radius ?cRad \
+            ] \
+        ] \
+    } \
+  FILTER(?cLat >= 39.16 && ?cLat <= 40.17 && ?cLon >= 63.94 && ?cLon <= 64.96) \
+} ORDER BY ASC(?name) LIMIT \
+"
+
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get 50 landmarks within coords (original) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+
+        def p_test_location_03 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon ?cAlt ?cRad \
+  ?nwLat ?nwLon ?nwAlt \
+  ?seLat ?seLon ?seAlt \
+  ?country ?district ?city ?street ?postalcode \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+  tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) as ?distance \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asPostalAddress \
+            [ \
+              a nco:PostalAddress ; \
+              nco:country ?country ; \
+              nco:region ?district ; \
+              nco:locality ?city ; \
+              nco:streetAddress ?street ; \
+              nco:postalcode ?postalcode \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asBoundingBox \
+            [ \
+              a mlo:GeoBoundingBox ; \
+              mlo:bbNorthWest \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?nwLat ; \
+                  mlo:longitude ?nwLon ; \
+                  mlo:altitude ?nwAlt \
+                ] ; \
+              mlo:bbSouthEast \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?seLat ; \
+                  mlo:longitude ?seLon ; \
+                  mlo:altitude ?seAlt \
+                ] \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:latitude ?cLat ; \
+              mlo:longitude ?cLon \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:altitude ?cAlt \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:radius ?cRad \
+            ] \
+        ] \
+    } \
+  FILTER(?cLat >= 39.16 && ?cLat <= 40.17 && \
+         ?cLon >= 63.94 && ?cLon <= 64.96 && \
+  	 tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) <= 25000) \
+} ORDER BY ASC(?distance) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get max 50 landmarks within certain range with bounding box (original) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+
+        def p_test_location_04 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon ?cAlt ?cRad \
+  ?nwLat ?nwLon ?nwAlt \
+  ?seLat ?seLon ?seAlt \
+  ?country ?district ?city ?street ?postalcode \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+  tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) as ?distance \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asPostalAddress \
+            [ \
+              a nco:PostalAddress ; \
+              nco:country ?country ; \
+              nco:region ?district ; \
+              nco:locality ?city ; \
+              nco:streetAddress ?street ; \
+              nco:postalcode ?postalcode \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asBoundingBox \
+            [ \
+              a mlo:GeoBoundingBox ; \
+              mlo:bbNorthWest \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?nwLat ; \
+                  mlo:longitude ?nwLon ; \
+                  mlo:altitude ?nwAlt \
+                ] ; \
+              mlo:bbSouthEast \
+                [ \
+                  a mlo:GeoPoint ; \
+                  mlo:latitude ?seLat ; \
+                  mlo:longitude ?seLon ; \
+                  mlo:altitude ?seAlt \
+                ] \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:latitude ?cLat ; \
+              mlo:longitude ?cLon \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:altitude ?cAlt \
+            ] \
+        ] \
+    } . \
+  OPTIONAL \
+    { \
+      ?urn mlo:location \
+        [ \
+          a mlo:GeoLocation ; \
+          mlo:asGeoPoint \
+            [ \
+              a mlo:GeoPoint ; \
+              mlo:radius ?cRad \
+            ] \
+        ] \
+    } \
+  FILTER(tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) <= 25000) \
+} ORDER BY ASC(?distance) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get max 50 landmarks within certain range without bounding box (original) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+        def p_test_location_05 (self):
+		query = " \
+SELECT \
+  ?urn \
+  mlo:latitude(?point) mlo:longitude(?point) mlo:altitude(?point) mlo:radius(?point) \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  ?urn mlo:location ?location . \
+  ?location mlo:asGeoPoint ?point . \
+} ORDER BY ASC(?name) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get 50 landmarks (simplified) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+
+        def p_test_location_06 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon mlo:altitude(?point) mlo:radius(?point) \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  ?urn mlo:location ?location . \
+  ?location mlo:asGeoPoint ?point . \
+  ?point mlo:latitude ?cLat . \
+  ?point mlo:longitude ?cLon . \
+  FILTER(?cLat >= 39.16 && ?cLat <= 40.17 && ?cLon >= 63.42 && ?cLon <= 64.96) \
+} ORDER BY ASC(?name) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get max 50 landmarks within coords (simplified) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+        def p_test_location_07 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon mlo:altitude(?point) mlo:radius(?point) \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+  tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) as ?distance \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  ?urn mlo:location ?location . \
+  ?location mlo:asGeoPoint ?point . \
+  ?point mlo:latitude ?cLat . \
+  ?point mlo:longitude ?cLon . \
+  FILTER(?cLat >= 39.16 && ?cLat <= 40.17 && \
+         ?cLon >= 63.94 && ?cLon <= 64.96 && \
+  	 tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) <= 25000) \
+} ORDER BY ASC(?distance) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get max 50 landmarks within range with bounding box (simplified) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
+        def p_test_location_08 (self):
+		query = " \
+SELECT \
+  ?urn \
+  ?cLat ?cLon mlo:altitude(?point) mlo:radius(?point) \
+  nie:title(?urn) \
+  nie:description(?urn) \
+  mlo:belongsToCategory(?urn) \
+  tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) as ?distance \
+WHERE { \
+  ?urn a mlo:Landmark . \
+  ?urn mlo:location ?location . \
+  ?location mlo:asGeoPoint ?point . \
+  ?point mlo:latitude ?cLat . \
+  ?point mlo:longitude ?cLon . \
+  FILTER(tracker:haversine-distance(xsd:double(?cLat),xsd:double(39.50),xsd:double(?cLon),xsd:double(64.50)) <= 25000) \
+} ORDER BY ASC(?distance) LIMIT 50 \
+"
+		start=time.time()
+
+		result=self.resources.SparqlQuery(query)
+
+		elapse =time.time()-start
+		print "Time taken to get max 50 landmarks within range without bounding box (simplified) %s " %elapse
+		print "no. of items retrieved: %d" %len(result)
+
 if __name__ == "__main__":
         unittest.main()
 
